#!/usr/bin/ksh
cd "$(cd "$(dirname "$0")"; pwd)"
#------------------------------------------------------------------------------
# QDepth.ksh
# 
# Script to get depth of any transmit queues and the DLQ
# 
# 
# 20150909 T.Rob  New script
#------------------------------------------------------------------------------
# Fetch vars to construct log file name
_PROG=${0##*/} && QMGR=${1}
_DATE=`date "+%y%m%d-%H%M%S"`
_LOG=$_PROG.$QMGR.$_DATE.out

# Find the mqm/bin directory
_MQMBIN="$(dspmqver -f 128 -b)/bin"

# Execute a new shell with redirection of the log file
/usr/bin/ksh > $_LOG 2>&1 << EOF

# Make sure the QMgr is there and running before continuing
[[ \$(${_MQMBIN}/dspmq -m $QMGR | grep '(Running)' | wc -l | tr -d " ") != 1 ]] && print "\n${0##*/}: Queue Manager '$QMGR' not found or not running.\n" && exit 1

DLQ=\$(echo dis qmgr deadq | runmqsc $QMGR 2>&1 | grep 'DEADQ(' | sed 's|.* DEADQ(||' | sed 's|).*||' | tr -d ' ')
if [ -z \${DLQ} ]; then
  print "QMgr $QMGR does not specify a Dead Letter Queue"
else
  DPTH=\$(echo "dis q(\$DLQ)" | runmqsc $QMGR 2>&1 | grep 'CURDEPTH(' | sed 's|.* CURDEPTH(||' | sed 's|).*||')
  print "\$DLQ CURDEPTH(\$DPTH)\n"
fi

echo "dis ql(*) where(USAGE eq XMITQ) curdepth CLCHNAME" | runmqsc $QMGR | sed -e :a -e '$!N;s/\n   / /;ta' -e 'P;D' | sed 's|  *| |g' | grep ^AMQ | grep -v 'CURDEPTH(0)' | grep -v 'CURDEPTH( )' | sort | {
  while read XQDetails
  do 
    XMitQ=\$(echo \$XQDetails | sed 's|.* QUEUE(\([^)]*\)).*|\1|')
    Curdepth=\$(echo \$XQDetails | sed 's|.* CURDEPTH(\([^)]*\)).*|\1|')
    ClChName=\$(echo \$XQDetails | sed 's|.* CLCHNAME(\([^)]*\)).*|\1|' | tr -d ' ')
    if [ -z \${ClChName} ]; then
      for Chl in \$(echo "dis chl(*) where(XMITQ eq \$XMitQ)" | runmqsc $QMGR | grep 'CHANNEL(' | sed 's|.* CHANNEL(\([^)]*\)).*|\1|')
      do
        print "Channel=\$Chl, XMitQ=\$XMitQ(\$Curdepth)"
      done
    else
      print "Channel=\$ClChName, XMitQ=\$XMitQ(\$Curdepth)"
    fi
  done
} | sort

#-----------------------------------------------------------------
#                  E N D   O F   S C R I P T
#-----------------------------------------------------------------
EOF
cat $_LOG
